# -*- coding: utf-8 -*-
from requests import Session

from ..exception.api import raise_response_exception

__docformat__ = 'reStructuredText'


class RelativeSession(Session):
    def __init__(self, base_url, **kwargs):
        """
        A :class:`requests.Session` subclass that prepends a base url to all requests.
        :param str base_url: the base url
        """
        super(RelativeSession, self).__init__()
        self._base_url = base_url

    def request(self, method, url, **kwargs):
        return super(RelativeSession, self).request(method, self._base_url + url, **kwargs)


class RaiseForStatusSession(Session):
    def __init__(self, *args, **kwargs):
        """
        A :class:`requests.Session` subclass that always raises_for_status on each request
        throwing a :class:`..exception.api.ClientHttpException` if necessary.
        """
        super(RaiseForStatusSession, self).__init__()

    def request(self, method, url, **kwargs):
        response = super(RaiseForStatusSession, self).request(method, url, **kwargs)
        raise_response_exception(response)
        return response


class RelativeRaiseForStatusSession(RelativeSession, RaiseForStatusSession):
    def __init__(self, *args, **kwargs):
        """
        A :class:`requests.Session` subclass that includes functionality from
        both :class:`RelativeSession` and :class:`RaiseForStatusSession`
        :param str base_url: the base url
        """
        super(RelativeRaiseForStatusSession, self).__init__(*args, **kwargs)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='pureport-client',
    version='0.0.4',
    author='Pureport',
    author_email='noreply@pureport.com',
    license='MIT',
    description='An API client for the Pureport ReST API',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/pureport/pureport-python-client',
    packages=find_packages(),
    namespace_packages=[
        'pureport',
        'pureport.api',
        'pureport.exception',
        'pureport.util'
    ],
    install_requires=[
        'requests',
        'enum34'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 2',
        'Operating System :: OS Independent',
    ]
)
